@@ -1,7 +1,7 @@
 #
 # Kiwi: a Framework and Enhanced Widgets for Python
 #
-# Copyright (C) 2002-2005 Async Open Source
+# Copyright (C) 2002-2007 Async Open Source
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -122,11 +122,8 @@ class Proxy:
 
         attribute = widget.get_property('model-attribute')
         if not attribute:
-            raise ProxyError(
-                "The widget %s (%s) in view %s is a kiwi widget but does "
-                "not have a model attribute set so it will not be "
-                "associated with the model" % (
-                widget_name, widget, self._view.__class__.__name__))
+            attribute = widget_name
+            widget.set_property('model-attribute', widget_name)
 
         # Do a isinstance here instead of in the callback,
         # as an optimization, it'll never change in runtime anyway
@@ -282,8 +279,8 @@ class Proxy:
                 # safe to return here since you shouldn't need to code
                 # around the lack of a model in your callbacks if you
                 # can help it.
-                value = None 
-            else: 
+                value = None
+            else:
                 value = kgetattr(self._model, attribute, ValueUnset)
 
         widget = self._model_attributes.get(attribute, None)
